==> views_slideshow_swiper-7.x-1.0.tar.gz: views_slideshow_swiper/js/views_slideshow_swiper.js <==
(function ($) {
  // @todo convert to use Drupal.behaviors
  // @todo add configuration options

  // Register callback to save references to Swiper instances. Allows
  // Views Slideshow controls to affect the slider
  function views_slideshow_swiper_register(fullId, slider) {
    Drupal.viewsSlideshowSwiper.active = Drupal.viewsSlideshowSwiper.active || {};
    Drupal.viewsSlideshowSwiper.active[fullId] = slider;
  }

  Drupal.behaviors.viewsSlideshowSwiper = {
    attach: function (context) {
      $('.views_slideshow_swiper_main:not(.views_slideshow_swiper-processed)', context).addClass('views_slideshow_swiper-processed').each(function() {
        // Get the ID of the slideshow
        var fullId = '#' + $(this).attr('id');

        // Create settings container
        var settings = Drupal.settings.viewsSlideshowSwiper[fullId];

        // @todo map the settings from the form to their javascript equivalents
        settings.targetId = fullId;
        settings.loaded = false;

        Drupal.viewsSlideshowSwiper.load(fullId);
      });
    }
  };


  // Initialize the swiperjs object
  Drupal.viewsSlideshowSwiper = Drupal.viewsSlideshowSwiper || {};

  // Load mapping from Views Slideshow to Swiper
  Drupal.viewsSlideshowSwiper.load = function(fullId) {
    var settings = Drupal.settings.viewsSlideshowSwiper[fullId];

    // Ensure the slider isn't already loaded
    if (!settings.loaded) {
      settings.swiper = new Swiper(settings.targetId, settings.options);
      settings.loaded = true;
    }
  };

  //~ Drupal.viewsSlideshowSwiper.transitionBegin = function (options) {
  //~ }

  //~ Drupal.viewsSlideshowSwiper.transitionEnd = function (options) {
  //~ }

  Drupal.viewsSlideshowSwiper.goToSlide = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.slideTo(options.slideNum);
  };

  // Pause mapping from Views Slideshow to Swiper
  Drupal.viewsSlideshowSwiper.pause = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.stopAutoplay();
  };

  // Play mapping from Views Slideshow to Swiper
  Drupal.viewsSlideshowSwiper.play = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.startAutoplay();
  };
  
  Drupal.viewsSlideshowSwiper.nextSlide = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.slideNext();
  };
  
  Drupal.viewsSlideshowSwiper.previousSlide = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.slidePrev();
  };
  // @todo add support for jquery mobile page init
})(jQuery);

==> views_slideshow_swiper-7.x-1.1.tar.gz: views_slideshow_swiper/js/views_slideshow_swiper.js <==
(function ($) {
  // @todo convert to use Drupal.behaviors
  // @todo add configuration options

  // Register callback to save references to Swiper instances. Allows
  // Views Slideshow controls to affect the slider
  function views_slideshow_swiper_register(fullId, slider) {
    Drupal.viewsSlideshowSwiper.active = Drupal.viewsSlideshowSwiper.active || {};
    Drupal.viewsSlideshowSwiper.active[fullId] = slider;
  }

  Drupal.behaviors.viewsSlideshowSwiper = {
    attach: function (context) {
      $('.views_slideshow_swiper_main:not(.views_slideshow_swiper-processed)', context).addClass('views_slideshow_swiper-processed').each(function() {
        // Get the ID of the slideshow
        var fullId = '#' + $(this).attr('id');

        // Create settings container
        var settings = Drupal.settings.viewsSlideshowSwiper[fullId];

        var createFunction = (function() {
          function F(args) {
            return Function.apply(this, args);
          }
          F.prototype = Function.prototype;

          return function(args, body) {
            return new F(args.concat(body));
          }
        })();

        settings.loaded = false;

        Drupal.viewsSlideshowSwiper.load(fullId);
      });
    }
  };


  // Initialize the swiperjs object
  Drupal.viewsSlideshowSwiper = Drupal.viewsSlideshowSwiper || {};

  // Load mapping from Views Slideshow to Swiper
  Drupal.viewsSlideshowSwiper.load = function(fullId) {
    var settings = Drupal.settings.viewsSlideshowSwiper[fullId];

    // Ensure the slider isn't already loaded
    if (!settings.loaded) {
      settings.swiper = new Swiper(settings.id_prefix + settings.vss_id, settings.options);
      settings.loaded = true;
    }
  };

  //~ Drupal.viewsSlideshowSwiper.transitionBegin = function (options) {
  //~ }

  //~ Drupal.viewsSlideshowSwiper.transitionEnd = function (options) {
  //~ }

  Drupal.viewsSlideshowSwiper.goToSlide = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.slideTo(options.slideNum);
  };

  // Pause mapping from Views Slideshow to Swiper
  Drupal.viewsSlideshowSwiper.pause = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.stopAutoplay();
  };

  // Play mapping from Views Slideshow to Swiper
  Drupal.viewsSlideshowSwiper.play = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.startAutoplay();
  };
  
  Drupal.viewsSlideshowSwiper.nextSlide = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.slideNext();
  };
  
  Drupal.viewsSlideshowSwiper.previousSlide = function (options) {
    Drupal.settings.viewsSlideshowSwiper[options.slideshowID].swiper.slidePrev();
  };
  // @todo add support for jquery mobile page init
})(jQuery);
